@@ -51,6 +51,7 @@ from .graphql_utils import (
     GraphQLEnvironment,
 )
 from .type_registry import TypeRegistry
+from .verbosity import VerbosityEnum
 from .wait import Wait
 
 LOGGER = logging.getLogger(__name__)
@@ -108,7 +109,8 @@ class QctrlGraphQLEnvironment(GraphQLEnvironment):
     def wait_for_completion(
         self,
         refresh_query: Union[RefreshActionQuery, MultiRefreshActionQuery],
-        *async_results: AsyncResult
+        *async_results: AsyncResult,
+        verbosity: VerbosityEnum,
     ):
         """Waits until the corresponding actions are completed on the server."""
         promise = AsyncResultCollection(*async_results)
@@ -118,7 +120,8 @@ class QctrlGraphQLEnvironment(GraphQLEnvironment):
 
         _wait = Wait()
 
-        with tqdm(total=100, leave=False) as progress_bar:
+        hide_progress_bar = verbosity == VerbosityEnum.QUIET
+        with tqdm(total=100, leave=False, disable=hide_progress_bar) as progress_bar:
 
             while not promise.is_completed:
 
@@ -128,7 +131,7 @@ class QctrlGraphQLEnvironment(GraphQLEnvironment):
 
                 # check completion
                 response = refresh_query(*promise.get_action_ids())
-                promise.update_data(self, response, progress_bar)
+                promise.update_data(self, response, progress_bar, verbosity)
 
             progress_bar.update(max(0, progress_bar.total - progress_bar.n))
 
