@@ -221,7 +221,7 @@ class QctrlOAuth2Session(OAuth2Session):
         Fetch token from authorization response and save it if `token_updater`
         is present.
         """
-        print("Finalising authentication...")
+        print("Finalizing authentication...")
         token = self.fetch_token(
             self.token_url, authorization_response=authorization_response
         )
