@@ -11,13 +11,11 @@
 # distributed under the License is distributed on an "AS IS" BASIS. See the
 # License for the specific language.
 # pylint:disable=missing-module-docstring
-import csv
 import hashlib
 import json
 import logging
 from pathlib import Path
 from typing import (
-    Any,
     Dict,
     List,
     Union,
@@ -77,25 +75,6 @@ def write_auth_file(token: TokenType, file_path: Path) -> None:
         raise QctrlException("incorrect permissions for credentials file") from exc
 
 
-def _write_action_result_to_csv(path: str, actions: List[Dict[str, Any]]):
-    """
-    Covert action result to csv format
-
-    Parameters
-    ----------
-    path: str
-        Saved file path. It requires filename and file path (i.e path/filename.csv).
-    actions: List
-        List of action data.
-    """
-    with open(path, "w", encoding="utf-8") as file:
-        writer = csv.DictWriter(file, fieldnames=actions[0].keys())
-        writer.writeheader()
-        for json_dict_result in actions:
-            json_dict_result["user"] = json_dict_result["user"]["username"]
-            writer.writerow(json_dict_result)
-
-
 def _process_output(result: Dict, output: str = None) -> None:
     """
     Presents the gql response. The result would be printed or save to
