@@ -367,7 +367,7 @@ def print_environment_related_packages():
         "qctrlopencontrols",
         "qctrlpyquil",
         "qctrlqua",
-        "qctrltoolkit",
+        "boulderopaltoolkits",
         "qctrlvisualizer",
     ]
 
